@@ -7,6 +7,7 @@ import errno
 import datetime
 import traceback
 
+import yaml
 from loguru import logger
 from dotenv import load_dotenv
 
@@ -44,6 +45,7 @@ def _add_lvlname(record: dict):
         record['lvlname'] = 'CRIT'
     return record
 
+
 ## Printing message based on log level to stdout or stderr:
 def _std_sink(message):
     if message.record["level"].no < 40:
@@ -51,8 +53,9 @@ def _std_sink(message):
     else:
         sys.stderr.write(message)
 
+
 ## Custom json formatter:
-def _custom_json_formatter(record):
+def _custom_json_formatter(record: dict):
     _error = None
     if record['exception']:
         _error = {}
@@ -90,6 +93,7 @@ def _custom_json_formatter(record):
     return '{custom_json}\n'
 
 
+
 ## Checking logger module already exists or not:
 if os.getenv('__INIT_LOG_HANDLER__') is None:
     ## Loading environment variables from .env file, if it's exits:
@@ -125,14 +129,21 @@ if os.getenv('__INIT_LOG_HANDLER__') is None:
     }
 
     ## Loading configs from file, if it's exits:
-    _configs_file_path = os.path.join(_current_dir, 'configs', 'logger.json')
-    if os.path.isfile(_configs_file_path):
-        # _json_configs = {}
+    _yaml_configs_file_path = os.path.join(_current_dir, 'configs', 'logger.yaml')
+    _json_configs_file_path = os.path.join(_current_dir, 'configs', 'logger.json')
+    if os.path.isfile(_yaml_configs_file_path):
         try:
-            with open(_configs_file_path, 'r') as _json_configs_file:
+            with open(_yaml_configs_file_path, 'r') as _yaml_configs_file:
+                _configs_dict = yaml.safe_load(_yaml_configs_file)
+        except Exception:
+            logger.exception(f"Failed to load '{_yaml_configs_file_path}' configs file.")
+            exit(2)
+    elif os.path.isfile(_json_configs_file_path):
+        try:
+            with open(_json_configs_file_path, 'r') as _json_configs_file:
                 _configs_dict = json.load(_json_configs_file)
         except Exception:
-            logger.exception(f"Failed to load '{_configs_file_path}' configs file.")
+            logger.exception(f"Failed to load '{_json_configs_file_path}' configs file.")
             exit(2)
 
     _configs_dict['is_debug'] = False
